# Readers

## HDF5

::: cfd_io.readers.hdf5.read_hdf5

## Plot3D

::: cfd_io.readers.plot3d.read_plot3d

::: cfd_io.readers.plot3d_flow.read_plot3d_flow

## Tecplot ASCII

::: cfd_io.readers.tecplot_ascii.read_tecplot_ascii

## Fortran Binary Sequential

::: cfd_io.readers.fortran_binary_sequential.FortranBinaryReader

## Binary Direct (split format)

::: cfd_io.readers.fortran_binary_direct.BinaryHeader

::: cfd_io.readers.fortran_binary_direct.read_header

::: cfd_io.readers.fortran_binary_direct.read_binary_direct

::: cfd_io.readers.fortran_binary_direct.read_binary_direct_xy_plane

::: cfd_io.readers.fortran_binary_direct.read_binary_direct_x_line

::: cfd_io.readers.fortran_binary_direct.read_binary_direct_xyz_volume